==> duiba-live-supplier-center-api-0.0.1-20220112.035109-22-sources.jar: cn/com/duiba/supplier/center/api/remoteservice/RemoteSupplierGoodsAuditService.java <==
package cn.com.duiba.supplier.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.supplier.center.api.base.PageResp;
import cn.com.duiba.supplier.center.api.dto.DuibaLiveSupplierGoodsAuditDto;
import cn.com.duiba.supplier.center.api.params.DuibaLiveSupplierGoodsAuditPageParam;

import java.util.List;

/**
 * @Author: fss
 * @Date: 2022/1/8 18
 * @Description:
 */
@AdvancedFeignClient
public interface RemoteSupplierGoodsAuditService {

    Integer insert(DuibaLiveSupplierGoodsAuditDto record);

    Integer insertSelective(DuibaLiveSupplierGoodsAuditDto record);

    DuibaLiveSupplierGoodsAuditDto selectByPrimaryKey(Long id);

    DuibaLiveSupplierGoodsAuditDto selectCurrentAuditByDuibaItemId(Long itemId);

    Integer updateByPrimaryKeySelective(DuibaLiveSupplierGoodsAuditDto record);

    Integer updateByPrimaryKey(DuibaLiveSupplierGoodsAuditDto record);

    /**
     * 分页查询兑吧直播供应商商品审核列表
     * @param param 查询参数
     * @return 列表
     */
    List<DuibaLiveSupplierGoodsAuditDto> page(DuibaLiveSupplierGoodsAuditPageParam param);

    /**
     * 查询总数
     * @param param 查询参数
     * @return 总数
     */
    int countForPage(DuibaLiveSupplierGoodsAuditPageParam param);

    /**
     * 分页查询审核列表
     * @param duibaLiveSupplierGoodsAuditPageParam 搜索条件
     * @param count 是否查询总条数
     * @return 列表
     */
    PageResp<DuibaLiveSupplierGoodsAuditDto> pageWithCount(DuibaLiveSupplierGoodsAuditPageParam duibaLiveSupplierGoodsAuditPageParam, Boolean count);

    /**
     * 更新审核单轧辊台
     * @param record
     * @return
     */
    Integer updateAuditStatus(DuibaLiveSupplierGoodsAuditDto record);
}

==> duiba-live-supplier-center-api-0.0.1-20220112.063330-24-sources.jar: cn/com/duiba/supplier/center/api/remoteservice/RemoteSupplierGoodsAuditService.java <==
package cn.com.duiba.supplier.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.supplier.center.api.base.PageResp;
import cn.com.duiba.supplier.center.api.dto.DuibaLiveSupplierGoodsAuditDto;
import cn.com.duiba.supplier.center.api.params.DuibaLiveMngSupplierGoodsAuditPageParam;
import cn.com.duiba.supplier.center.api.params.DuibaLiveSupplierGoodsAuditPageParam;

import java.util.List;

/**
 * @Author: fss
 * @Date: 2022/1/8 18
 * @Description:
 */
@AdvancedFeignClient
public interface RemoteSupplierGoodsAuditService {

    Integer insert(DuibaLiveSupplierGoodsAuditDto record);

    Integer insertSelective(DuibaLiveSupplierGoodsAuditDto record);

    DuibaLiveSupplierGoodsAuditDto selectByPrimaryKey(Long id);

    DuibaLiveSupplierGoodsAuditDto selectCurrentAuditByDuibaItemId(Long itemId);

    Integer updateByPrimaryKeySelective(DuibaLiveSupplierGoodsAuditDto record);

    Integer updateByPrimaryKey(DuibaLiveSupplierGoodsAuditDto record);

    /**
     * 分页查询兑吧直播供应商商品审核列表
     * @param param 查询参数
     * @return 列表
     */
    List<DuibaLiveSupplierGoodsAuditDto> page(DuibaLiveSupplierGoodsAuditPageParam param);

    /**
     * 查询总数
     * @param param 查询参数
     * @return 总数
     */
    int countForPage(DuibaLiveSupplierGoodsAuditPageParam param);

    /**
     * 分页查询审核列表
     * @param duibaLiveSupplierGoodsAuditPageParam 搜索条件
     * @param count 是否查询总条数
     * @return 列表
     */
    PageResp<DuibaLiveSupplierGoodsAuditDto> pageWithCount(DuibaLiveMngSupplierGoodsAuditPageParam duibaLiveSupplierGoodsAuditPageParam, Boolean count);

    /**
     * 更新审核单轧辊台
     * @param record
     * @return
     */
    Integer updateAuditStatus(DuibaLiveSupplierGoodsAuditDto record);
}
